@@ -2,10 +2,11 @@
 /*!	\file lyr_freetype/main.cpp
 **	\brief Template Header
 **
-**	$Id: main.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: main.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -58,7 +59,7 @@ bool freetype_constructor(synfig::ProgressCallback *cb)
 	if(cb)cb->task("Initializing FreeType...");
 	if ( (error = FT_Init_FreeType( &ft_library )) )
 	{
-		if(cb)cb->error(strprintf("lyr_freetype: FreeType initialization failed. (err=%d)",error));
+		if(cb)cb->error(strprintf("Layer_Freetype: FreeType initialization failed. (err=%d)",error));
 		return false;
 	}
 	return true;
@@ -84,7 +85,7 @@ MODULE_DESC_END
 
 MODULE_INVENTORY_BEGIN(liblyr_freetype)
 	BEGIN_LAYERS
-		LAYER(lyr_freetype)
-		LAYER_ALIAS(lyr_freetype,"Text")
+		LAYER(Layer_Freetype)
+		LAYER_ALIAS(Layer_Freetype,"Text")
 	END_LAYERS
 MODULE_INVENTORY_END
