@@ -2,10 +2,11 @@
 /*!	\file import.cpp
 **	\brief Image Import Layer Implementation
 **
-**	$Id: import.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: import.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -54,10 +55,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Import);
 SYNFIG_LAYER_SET_NAME(Import,"import");
-SYNFIG_LAYER_SET_LOCAL_NAME(Import,_("Import"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Import,_("Import Image"));
 SYNFIG_LAYER_SET_CATEGORY(Import,_("Other"));
 SYNFIG_LAYER_SET_VERSION(Import,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Import,"$Id: import.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Import,"$Id: import.cpp 848 2007-10-06 02:25:36Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -83,7 +84,7 @@ Import::set_param(const String & param, const ValueBase &value)
 {
 	try{
 	IMPORT(time_offset);
-	if(param=="filename" && value.same_as(filename))
+	if(param=="filename" && value.same_type_as(filename))
 	{
 		if(!get_canvas())
 		{
@@ -98,7 +99,7 @@ Import::set_param(const String & param, const ValueBase &value)
 
 		// Get rid of any %20 crap
 		{
-			unsigned int n;
+			String::size_type n;
 			while((n=newfilename.find("%20"))!=String::npos)
 				newfilename.replace(n,3," ");
 		}
@@ -143,7 +144,7 @@ Import::set_param(const String & param, const ValueBase &value)
 		if(is_absolute_path(newfilename))
 			filename_with_path=newfilename;
 		else
-			filename_with_path=get_canvas()->get_file_path()+ETL_DIRECTORY_SEPERATOR+newfilename;
+			filename_with_path=get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+newfilename;
 
 		handle<Importer> newimporter;
 
@@ -151,7 +152,7 @@ Import::set_param(const String & param, const ValueBase &value)
 
 		if(!newimporter)
 		{
-			newimporter=Importer::open(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPERATOR+basename(newfilename));
+			newimporter=Importer::open(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+basename(newfilename));
 			if(!newimporter)
 			{
 				synfig::error(strprintf("Unable to create an importer object with file \"%s\"",filename_with_path.c_str()));
