@@ -2,10 +2,11 @@
 /*!	\file lyr_std/main.cpp
 **	\brief Template Header
 **
-**	$Id: main.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: main.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -80,31 +81,18 @@ MODULE_DESC_END
 
 MODULE_INVENTORY_BEGIN(liblyr_std)
 	BEGIN_LAYERS
-		LAYER(Zoom)
-//		LAYER(Blur_Layer)
-//		LAYER(RadialBlur)
-		LAYER(Import)
-		LAYER(Translate)
-		LAYER(SuperSample)
-		LAYER(Rotate)
+		LAYER(Zoom)				LAYER_ALIAS(Zoom,"Zoom")
+		LAYER(Import)			LAYER_ALIAS(Import,"Import")
+		LAYER(Translate)		LAYER_ALIAS(Translate,"Translate")
+		LAYER(SuperSample)		LAYER_ALIAS(SuperSample,"SuperSample")
+		LAYER(Rotate)			LAYER_ALIAS(Rotate,"Rotate")
 		LAYER(Warp)
-
-		LAYER_ALIAS(Zoom,"Zoom")
-		LAYER_ALIAS(Translate,"Translate")
-		LAYER_ALIAS(SuperSample,"SuperSample")
-		LAYER_ALIAS(Rotate,"Rotate")
-		LAYER_ALIAS(Import,"Import")
-//		LAYER_ALIAS(Blur_Layer,"Blur")
-
-//		LAYER(Halftone2)
-
 		LAYER(Julia)
 		LAYER(InsideOut)
 		LAYER(Mandelbrot)
 		LAYER(Layer_Clamp)
 		LAYER(Layer_Stretch)
-//		LAYER(Layer_ColorCorrect)
-//		LAYER(XORPattern)
+		LAYER(XORPattern)		LAYER_ALIAS(XORPattern,"XORPattern")
 		LAYER(Twirl)
 		LAYER(Layer_Shade)
 		LAYER(Layer_Bevel)
