@@ -2,7 +2,7 @@
 /*!	\file shade.cpp
 **	\brief Template Header
 **
-**	$Id: shade.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: shade.cpp 859 2007-10-07 22:45:42Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -53,9 +53,7 @@ using namespace std;
 
 /*#define TYPE_BOX			0
 #define TYPE_FASTGUASSIAN	1
-#define TYPE_FASTGAUSSIAN	1
 #define TYPE_CROSS			2
-#define TYPE_GUASSIAN		3
 #define TYPE_GAUSSIAN		3
 #define TYPE_DISC			4
 */
@@ -67,7 +65,7 @@ SYNFIG_LAYER_SET_NAME(Layer_Shade,"shade");
 SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Shade,_("Shade"));
 SYNFIG_LAYER_SET_CATEGORY(Layer_Shade,_("Stylize"));
 SYNFIG_LAYER_SET_VERSION(Layer_Shade,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Shade,"$Id: shade.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Shade,"$Id: shade.cpp 859 2007-10-07 22:45:42Z dooglus $");
 
 /* -- F U N C T I O N S ----------------------------------------------------- */
 
