@@ -1,8 +1,10 @@
-/*! ========================================================================
-** Synfig
-** Template File
-** $Id: supersample.cpp,v 1.1.1.1 2005/01/04 01:23:10 darco Exp $
+/* === S Y N F I G ========================================================= */
+/*!	\file supersample.cpp
+**	\brief Template Header
 **
+**	$Id: supersample.cpp 373 2007-03-23 16:02:09Z dooglus $
+**
+**	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **
 **	This package is free software; you can redistribute it and/or
@@ -14,6 +16,7 @@
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 **	General Public License for more details.
+**	\endlegal
 **
 ** === N O T E S ===========================================================
 **
@@ -52,7 +55,7 @@ SYNFIG_LAYER_SET_NAME(SuperSample,"super_sample");
 SYNFIG_LAYER_SET_LOCAL_NAME(SuperSample,_("Super Sample"));
 SYNFIG_LAYER_SET_CATEGORY(SuperSample,_("Other"));
 SYNFIG_LAYER_SET_VERSION(SuperSample,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(SuperSample,"$Id: supersample.cpp,v 1.1.1.1 2005/01/04 01:23:10 darco Exp $");
+SYNFIG_LAYER_SET_CVS_ID(SuperSample,"$Id: supersample.cpp 373 2007-03-23 16:02:09Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -72,7 +75,7 @@ SuperSample::set_param(const String & param, const ValueBase &value)
 	IMPORT(height);
 	IMPORT(scanline);
 	IMPORT(alpha_aware);
-	
+
 	return false;
 }
 
@@ -83,7 +86,7 @@ SuperSample::get_param(const String& param)const
 	EXPORT(height);
     EXPORT(scanline);
     EXPORT(alpha_aware);
-	
+
 	EXPORT_NAME();
 	EXPORT_VERSION();
 
@@ -96,7 +99,7 @@ SuperSample::accelerated_render(Context context,Surface *surface,int quality, co
 	// don't bother supersampling if our quality is too low.
 	if(quality>=10)
 		return context.accelerated_render(surface,quality,renddesc,cb);
-	
+
 	RendDesc desc(renddesc);
 
 	SuperCallback subcb(cb,1,9000,10000);
@@ -197,9 +200,9 @@ SuperSample::accelerated_render(Context context,Surface *surface,int quality, co
 			}
 		}
 	}
-	
+
 	if(cb && !cb->amount_complete(10000,10000)) return false;
-	
+
 	return true;
 }
 
@@ -223,7 +226,7 @@ SuperSample::get_param_vocab(void)const
 	ret.push_back(ParamDesc("alpha_aware")
 		.set_local_name(_("Be Alpha Safe"))
 	);
-	
+
 	return ret;
 }
 
