@@ -2,7 +2,7 @@
 /*!	\file zoom.cpp
 **	\brief writeme
 **
-**	$Id: zoom.cpp,v 1.2 2005/01/24 03:08:17 darco Exp $
+**	$Id: zoom.cpp 377 2007-03-23 21:06:51Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,7 +51,7 @@ SYNFIG_LAYER_SET_NAME(Zoom,"zoom");
 SYNFIG_LAYER_SET_LOCAL_NAME(Zoom,_("Zoom"));
 SYNFIG_LAYER_SET_CATEGORY(Zoom,_("Transform"));
 SYNFIG_LAYER_SET_VERSION(Zoom,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Zoom,"$Id: zoom.cpp,v 1.2 2005/01/24 03:08:17 darco Exp $");
+SYNFIG_LAYER_SET_CVS_ID(Zoom,"$Id: zoom.cpp 377 2007-03-23 21:06:51Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -64,14 +64,14 @@ Zoom::Zoom():
 	amount(0)
 {
 }
-	
+
 bool
 Zoom::set_param(const String & param, const ValueBase &value)
 {
 
 	IMPORT(center);
 	IMPORT(amount);
-	
+
 	return false;
 }
 
@@ -83,15 +83,15 @@ Zoom::get_param(const String &param)const
 
 	EXPORT_NAME();
 	EXPORT_VERSION();
-		
-	return ValueBase();	
+
+	return ValueBase();
 }
 
 Layer::Vocab
 Zoom::get_param_vocab()const
 {
 	Layer::Vocab ret;
-	
+
 	ret.push_back(ParamDesc("amount")
 		.set_local_name(_("Amount"))
 		.set_description(_("Amount to zoom in"))
@@ -101,7 +101,7 @@ Zoom::get_param_vocab()const
 		.set_local_name(_("Center"))
 		.set_description(_("Point to zoom in to"))
 	);
-	
+
 	return ret;
 }
 
@@ -122,12 +122,12 @@ class Zoom_Trans : public Transform
 	etl::handle<const Zoom> layer;
 public:
 	Zoom_Trans(const Zoom* x):Transform(x->get_guid()),layer(x) { }
-	
+
 	synfig::Vector perform(const synfig::Vector& x)const
 	{
 		return (x-layer->center)*exp(layer->amount)+layer->center;
 	}
-	
+
 	synfig::Vector unperform(const synfig::Vector& x)const
 	{
 		return (x-layer->center)/exp(layer->amount)+layer->center;
@@ -158,6 +158,5 @@ Zoom::accelerated_render(Context context,Surface *surface,int quality, const Ren
 synfig::Rect
 Zoom::get_full_bounding_rect(synfig::Context context)const
 {
-	return context.get_full_bounding_rect();
+	return (context.get_full_bounding_rect()-center)*exp(amount)+center;
 }
-
