@@ -2,7 +2,7 @@
 /*!	\file trgt_ffmpeg.cpp
 **	\brief ppm Target Module
 **
-**	$Id: trgt_ffmpeg.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: trgt_ffmpeg.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -54,7 +54,7 @@ SYNFIG_TARGET_INIT(ffmpeg_trgt);
 SYNFIG_TARGET_SET_NAME(ffmpeg_trgt,"ffmpeg");
 SYNFIG_TARGET_SET_EXT(ffmpeg_trgt,"mpg");
 SYNFIG_TARGET_SET_VERSION(ffmpeg_trgt,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(ffmpeg_trgt,"$Id: trgt_ffmpeg.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(ffmpeg_trgt,"$Id: trgt_ffmpeg.cpp 631 2007-09-08 15:33:07Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -150,7 +150,7 @@ ffmpeg_trgt::end_frame()
 }
 
 bool
-ffmpeg_trgt::start_frame(synfig::ProgressCallback *callback)
+ffmpeg_trgt::start_frame(synfig::ProgressCallback */*callback*/)
 {
 	int w=desc.get_w(),h=desc.get_h();
 
@@ -170,7 +170,7 @@ ffmpeg_trgt::start_frame(synfig::ProgressCallback *callback)
 }
 
 Color *
-ffmpeg_trgt::start_scanline(int scanline)
+ffmpeg_trgt::start_scanline(int /*scanline*/)
 {
 	return color_buffer;
 }
