@@ -2,10 +2,11 @@
 /*!	\file outline.cpp
 **	\brief Template
 **
-**	$Id: outline.cpp 446 2007-04-09 15:55:12Z dooglus $
+**	$Id: outline.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -69,7 +70,7 @@ SYNFIG_LAYER_SET_NAME(Outline,"outline");
 SYNFIG_LAYER_SET_LOCAL_NAME(Outline,_("Outline"));
 SYNFIG_LAYER_SET_CATEGORY(Outline,_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Outline,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Outline,"$Id: outline.cpp 446 2007-04-09 15:55:12Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Outline,"$Id: outline.cpp 848 2007-10-06 02:25:36Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -171,6 +172,13 @@ void
 Outline::sync()
 {
 	clear();
+
+	if (!bline.get_list().size())
+	{
+		synfig::warning(string("Outline::sync():")+_("No verticies in outline " + string("\"") + get_description() + string("\"")));
+		return;
+	}
+		
 	try {
 #if 1
 
@@ -721,7 +729,7 @@ Outline::set_param(const String & param, const ValueBase &value)
 		return true;
 	}
 
-	if(	param=="width_list" && value.same_as(width_list))
+	if(	param=="width_list" && value.same_type_as(width_list))
 	{
 		width_list=value;
 		//sync();
