@@ -1,8 +1,10 @@
-/*! ========================================================================
-** Synfig
-** Template Header File
-** $Id: mptr_jpeg.h,v 1.1.1.1 2005/01/04 01:23:11 darco Exp $
+/* === S Y N F I G ========================================================= */
+/*!	\file mptr_jpeg.h
+**	\brief Template Header
 **
+**	$Id: mptr_jpeg.h 335 2007-03-16 00:39:09Z dooglus $
+**
+**	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **
 **	This package is free software; you can redistribute it and/or
@@ -14,6 +16,7 @@
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 **	General Public License for more details.
+**	\endlegal
 **
 ** === N O T E S ===========================================================
 **
@@ -56,7 +59,7 @@ public:
 	jpeg_mptr(const char *filename);
 	~jpeg_mptr();
 
-	virtual bool get_frame(synfig::Surface &,synfig::Time, synfig::ProgressCallback *);
+	virtual bool get_frame(synfig::Surface &surface,synfig::Time time, synfig::ProgressCallback *callback);
 };
 
 /* === E N D =============================================================== */
