@@ -2,7 +2,7 @@
 /*!	\file mptr.cpp
 **	\brief writeme
 **
-**	$Id: mptr.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: mptr.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,7 +51,7 @@ SYNFIG_IMPORTER_INIT(Importer_LibAVCodec);
 SYNFIG_IMPORTER_SET_NAME(Importer_LibAVCodec,"libav");
 SYNFIG_IMPORTER_SET_EXT(Importer_LibAVCodec,"avi");
 SYNFIG_IMPORTER_SET_VERSION(Importer_LibAVCodec,"0.1");
-SYNFIG_IMPORTER_SET_CVS_ID(Importer_LibAVCodec,"$Id: mptr.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_IMPORTER_SET_CVS_ID(Importer_LibAVCodec,"$Id: mptr.cpp 631 2007-09-08 15:33:07Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -66,7 +66,7 @@ Importer_LibAVCodec::~Importer_LibAVCodec()
 }
 
 bool
-Importer_LibAVCodec::get_frame(synfig::Surface &surface,Time, synfig::ProgressCallback *cb)
+Importer_LibAVCodec::get_frame(synfig::Surface &/*surface*/,Time, synfig::ProgressCallback */*cb*/)
 {
 	return false;
 }
