@@ -2,7 +2,7 @@
 /*!	\file trgt_av.cpp
 **	\brief \writeme
 **
-**	$Id: trgt_av.cpp 465 2007-04-12 15:10:11Z dooglus $
+**	$Id: trgt_av.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -61,7 +61,7 @@ SYNFIG_TARGET_INIT(Target_LibAVCodec);
 SYNFIG_TARGET_SET_NAME(Target_LibAVCodec,"libav");
 SYNFIG_TARGET_SET_EXT(Target_LibAVCodec,"avi");
 SYNFIG_TARGET_SET_VERSION(Target_LibAVCodec,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(Target_LibAVCodec,"$Id: trgt_av.cpp 465 2007-04-12 15:10:11Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(Target_LibAVCodec,"$Id: trgt_av.cpp 631 2007-09-08 15:33:07Z dooglus $");
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
@@ -454,7 +454,7 @@ public:
 		return true;
 	}
 
-	void close(AVFormatContext *formatc, AVStream *stream)
+	void close(AVFormatContext */*formatc*/, AVStream *stream)
 	{
 		if(stream)
 			avcodec_close(stream->codec);
@@ -745,7 +745,7 @@ public:
 	}
 
 	// add an audio output stream
-	AVStream *add_audio_stream(int codec_id,const AudioInfo &aInfo)
+	AVStream *add_audio_stream(int codec_id,const AudioInfo &/*aInfo*/)
 	{
 		AVCodecContext *context;
 		AVStream *stream;
@@ -905,7 +905,7 @@ Target_LibAVCodec::end_frame()
 }
 
 bool
-Target_LibAVCodec::start_frame(synfig::ProgressCallback *callback)
+Target_LibAVCodec::start_frame(synfig::ProgressCallback */*callback*/)
 {
 	//prepare all the color buffer stuff, etc.
 
