@@ -2,10 +2,11 @@
 /*!	\file plant.h
 **	\brief Template Header
 **
-**	$Id: plant.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: plant.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -72,6 +73,7 @@ private:
 	synfig::Angle split_angle;
 	synfig::Vector gravity;
 	synfig::Real velocity;
+	synfig::Real perp_velocity;
 	synfig::Real step;
 	synfig::Real mass;
 	synfig::Real drag;
@@ -83,16 +85,15 @@ private:
 
 	bool size_as_alpha;
 	mutable bool needs_sync_;
-
+	mutable synfig::Mutex mutex;
 
 	void branch(int n, int depth,float t, float stunt_growth, synfig::Point position,synfig::Vector velocity)const;
+	void sync()const;
 
 public:
 
 	Plant();
 
-	void sync()const;
-
 	void calc_bounding_rect()const;
 
 	virtual bool set_param(const String & param, const synfig::ValueBase &value);
