@@ -2,7 +2,7 @@
 /*!	\file trgt_yuv.cpp
 **	\brief Template File
 **
-**	$Id: trgt_yuv.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: trgt_yuv.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -58,7 +58,7 @@ SYNFIG_TARGET_INIT(yuv);
 SYNFIG_TARGET_SET_NAME(yuv,"yuv420p");
 SYNFIG_TARGET_SET_EXT(yuv,"yuv");
 SYNFIG_TARGET_SET_VERSION(yuv,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(yuv,"$Id: trgt_yuv.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(yuv,"$Id: trgt_yuv.cpp 631 2007-09-08 15:33:07Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -93,7 +93,7 @@ yuv::set_rend_desc(RendDesc *given_desc)
 }
 
 bool
-yuv::start_frame(synfig::ProgressCallback *callback)
+yuv::start_frame(synfig::ProgressCallback */*callback*/)
 {
 	return static_cast<bool>(file);
 }
