@@ -2,7 +2,7 @@
 /*!	\file synfig/blur.cpp
 **	\brief Blur Implementation File
 **
-**	$Id: blur.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: blur.cpp 857 2007-10-07 22:28:34Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -717,7 +717,7 @@ bool Blur::operator ()(const Surface &surface,
 			   is necessary to insure consistant
 			   results when rendered to different
 			   resolutions.
-			   Unfortunately, this automaticly
+			   Unfortunately, this automatically
 			   squares our rendertime.
 			   There has got to be a faster way...
 			*/
@@ -1091,7 +1091,7 @@ bool Blur::operator ()(const surface<float> &surface,
 			   is necessary to insure consistant
 			   results when rendered to different
 			   resolutions.
-			   Unfortunately, this automaticly
+			   Unfortunately, this automatically
 			   squares our rendertime.
 			   There has got to be a faster way...
 			*/
