@@ -2,10 +2,11 @@
 /*!	\file color.cpp
 **	\brief Color Class
 **
-**	$Id: color.cpp 404 2007-04-01 08:54:36Z dooglus $
+**	$Id: color.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -34,6 +35,7 @@
 #include <cstdio>
 #include <sstream>
 #include <iostream>
+#include <iomanip>
 
 #endif
 
@@ -47,8 +49,6 @@ using namespace std;
 
 /* === G L O B A L S ======================================================= */
 
-String Color::hex_;
-
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -111,6 +111,14 @@ Color::set_hex(String& hex)
 	}
 }
 
+const String
+Color::get_string(void)const
+{
+	std::ostringstream o;
+	o << std::fixed << std::setprecision(3) << "#" << get_hex() << " : " << std::setw(6) << a_;
+	return String(o.str().c_str());
+}
+
 #if 0
 Color&
 Color::rotate_uv(const Angle& theta)const
@@ -376,7 +384,7 @@ blendfunc_DIVIDE(Color &a,Color &b,float amount)
 
 	// We add COLOR_EPSILON in order to avoid a divide-by-zero condition.
 	// This causes DIVIDE to bias toward positive values, but the effect is
-	// really neglegable. There is a reason why we use COLOR_EPSILON--we
+	// really negligible. There is a reason why we use COLOR_EPSILON--we
 	// want the change to be imperceptable.
 
 	b.set_r(((b.get_r()/(a.get_r()+COLOR_EPSILON))-b.get_r())*(amount)+b.get_r());
