@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file general.h
-**	\brief General macros, classes, and prodecure declarations
+**	\brief General macros, classes, and procedure declarations
 **
-**	$Id: general.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: general.h 658 2007-09-12 20:36:47Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -83,10 +83,10 @@ class ProgressCallback
 public:
 
 	virtual ~ProgressCallback() { }
-	virtual bool task(const String &task) { return true; }
-	virtual bool error(const String &task) { return true; }
-	virtual bool warning(const String &task) { return true; }
-	virtual bool amount_complete(int current, int total) { return true; }
+	virtual bool task(const String &/*task*/) { return true; }
+	virtual bool error(const String &/*task*/) { return true; }
+	virtual bool warning(const String &/*task*/) { return true; }
+	virtual bool amount_complete(int /*current*/, int /*total*/) { return true; }
 
 	virtual bool valid() const { return true; }
 };
