@@ -2,7 +2,7 @@
 /*!	\file layer.h
 **	\brief Layer Class Header
 **
-**	$Id: layer.h 383 2007-03-24 19:45:42Z dooglus $
+**	$Id: layer.h 578 2007-09-03 19:13:34Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -62,10 +62,10 @@
 #define SYNFIG_LAYER_INIT(class) synfig::Layer* class::create() { return new class(); }
 
 //! \writeme
-#define IMPORT_PLUS(x,y) if(param==#x && value.same_as(x)) { value.put(&x);{y;}return true;}
+#define IMPORT_PLUS(x,y) if(param==#x && value.same_type_as(x)) { value.put(&x);{y;}return true;}
 
 //! \writeme
-#define IMPORT_AS(x,y) if(param==y && value.same_as(x)) { value.put(&x); return true;}
+#define IMPORT_AS(x,y) if(param==y && value.same_type_as(x)) { value.put(&x); return true;}
 
 //! \writeme
 #define IMPORT(x) IMPORT_AS(x,#x)
