@@ -2,10 +2,11 @@
 /*!	\file layer_pastecanvas.h
 **	\brief Template Header
 **
-**	$Id: layer_pastecanvas.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: layer_pastecanvas.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -62,9 +63,7 @@ private:
 
 	mutable Time curr_time;
 
-	bool optimize_layers(synfig::Context context,synfig::CanvasBase&)const;
-
-	bool do_not_muck_with_time_;
+	bool muck_with_time_;
 
 	bool children_lock;
 
@@ -75,7 +74,7 @@ public:
 
 	virtual void on_canvas_set();
 
-	void set_do_not_muck_with_time(bool x=true) { do_not_muck_with_time_=true; }
+	void set_muck_with_time(bool x=false) { muck_with_time_=x; }
 
 	etl::handle<synfig::Canvas> get_sub_canvas()const { return canvas; }
 	void set_sub_canvas(etl::handle<synfig::Canvas> x);
