@@ -2,10 +2,11 @@
 /*!	\file layer_shape.cpp
 **	\brief Template Header
 **
-**	$Id: layer_shape.cpp 465 2007-04-12 15:10:11Z dooglus $
+**	$Id: layer_shape.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -62,7 +63,7 @@ SYNFIG_LAYER_SET_NAME(Layer_Shape,"shape");
 SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Shape,_("Shape"));
 SYNFIG_LAYER_SET_CATEGORY(Layer_Shape,_("Internal"));
 SYNFIG_LAYER_SET_VERSION(Layer_Shape,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Shape,"$Id: layer_shape.cpp 465 2007-04-12 15:10:11Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Shape,"$Id: layer_shape.cpp 848 2007-10-06 02:25:36Z dooglus $");
 
 #define EPSILON	1e-12
 
@@ -233,7 +234,7 @@ struct MonoSegment
 
 	int intersect(Real x,Real y) const
 	{
-		if((y < aabb.miny) || (y > aabb.maxy) || (x < aabb.minx)) return 0;
+		if((y < aabb.miny+EPSILON) || (y > aabb.maxy) || (x < aabb.minx)) return 0;
 		if(x > aabb.maxx) return ydir;
 
 		//int i = 0;
@@ -316,7 +317,7 @@ struct CurveArray
 		degrees.push_back(2);
 	}
 
-	static int intersect_conic(Real x, Real y, Point *p, int level = 0)
+	static int intersect_conic(Real x, Real y, Point *p, int /*level*/ = 0)
 	{
 		Real ymin,ymax,xmin,xmax;
 		int intersects = 0;
@@ -471,7 +472,7 @@ struct CurveArray
 		}
 	}
 
-	static int intersect_cubic(Real x, Real y, Point *p, int level = 0)
+	static int intersect_cubic(Real x, Real y, Point *p, int /*level*/ = 0)
 	{
 		const Real INVALIDROOT = -FLT_MAX;
 		Real ymin,ymax,xmin,xmax;
@@ -1327,7 +1328,7 @@ void Layer_Shape::PolySpan::line_to(Real x, Real y)
 			//generate data for the ending clipped info
 			if(y > window.maxy)
 			{
-				//intial line to intersection (and degenerate)
+				//initial line to intersection (and degenerate)
 				n[2] = x + (window.maxy - y) * dx / dy;
 
 				//intersect coords
@@ -1351,7 +1352,7 @@ void Layer_Shape::PolySpan::line_to(Real x, Real y)
 			//generate data for the ending clipped info
 			if(y < window.miny)
 			{
-				//intial line to intersection (and degenerate)
+				//initial line to intersection (and degenerate)
 				n[2] = x + (window.miny - y) * dx / dy;
 
 				//intersect coords
@@ -1401,7 +1402,7 @@ void Layer_Shape::PolySpan::line_to(Real x, Real y)
 				//generate data for the ending clipped info
 				if(x > window.maxx)
 				{
-					//intial line to intersection (and degenerate)
+					//initial line to intersection (and degenerate)
 					n[2] = y + (window.maxx - x) * dy / dx;
 
 					n[0] = window.maxx;
@@ -1430,7 +1431,7 @@ void Layer_Shape::PolySpan::line_to(Real x, Real y)
 				//generate data for the ending clipped info
 				if(x < window.minx)
 				{
-					//intial line to intersection (and degenerate)
+					//initial line to intersection (and degenerate)
 					n[2] = y + (window.minx - x) * dy / dx;
 
 					n[0] = window.minx;
@@ -2614,7 +2615,7 @@ Layer_Shape::accelerated_render(Context context,Surface *surface,int quality, co
 }
 
 bool
-Layer_Shape::render_shape(Surface *surface,bool useblend,int quality,
+Layer_Shape::render_shape(Surface *surface,bool useblend,int /*quality*/,
 							const RendDesc &renddesc, ProgressCallback *cb)const
 {
 	int tmp(0);
@@ -2854,8 +2855,8 @@ Layer_Shape::render_shape(Surface *surface,bool useblend,int quality,
 }
 
 bool
-Layer_Shape::render_shape(surface<float> *surface,int quality,
-							const RendDesc &renddesc, ProgressCallback *cb)const
+Layer_Shape::render_shape(surface<float> *surface,int /*quality*/,
+							const RendDesc &renddesc, ProgressCallback */*cb*/)const
 {
 	// If our amount is set to zero, no need to render anything
 	if(!get_amount())
