@@ -2,10 +2,11 @@
 /*!	\file loadcanvas.h
 **	\brief writeme
 **
-**	$Id: loadcanvas.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: loadcanvas.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,11 +36,7 @@
 #include "valuenode_subtract.h"
 #include "valuenode_animated.h"
 #include "valuenode_composite.h"
-#include "valuenode_const.h"
-#include "valuenode_linear.h"
 #include "valuenode_dynamiclist.h"
-#include "valuenode_reference.h"
-#include "valuenode_timedswap.h"
 #include "keyframe.h"
 #include "guid.h"
 
@@ -144,18 +141,18 @@ private:
 
 	// ValueBase Parsing Functions
 
-	Real parse_real(xmlpp::Element *node,Canvas::Handle canvas);
+	Real parse_real(xmlpp::Element *node);
 	Time parse_time(xmlpp::Element *node,Canvas::Handle canvas);
-	int parse_integer(xmlpp::Element *node,Canvas::Handle canvas);
-	Vector parse_vector(xmlpp::Element *node,Canvas::Handle canvas);
-	Color parse_color(xmlpp::Element *node,Canvas::Handle canvas);
-	Angle parse_angle(xmlpp::Element *node,Canvas::Handle canvas);
-	String parse_string(xmlpp::Element *node,Canvas::Handle canvas);
-	bool parse_bool(xmlpp::Element *node,Canvas::Handle canvas);
-	Segment parse_segment(xmlpp::Element *node,Canvas::Handle canvas);
+	int parse_integer(xmlpp::Element *node);
+	Vector parse_vector(xmlpp::Element *node);
+	Color parse_color(xmlpp::Element *node);
+	Angle parse_angle(xmlpp::Element *node);
+	String parse_string(xmlpp::Element *node);
+	bool parse_bool(xmlpp::Element *node);
+	Segment parse_segment(xmlpp::Element *node);
 	ValueBase parse_list(xmlpp::Element *node,Canvas::Handle canvas);
-	Gradient parse_gradient(xmlpp::Element *node,Canvas::Handle canvas);
-	BLinePoint parse_bline_point(xmlpp::Element *node,Canvas::Handle canvas);
+	Gradient parse_gradient(xmlpp::Element *node);
+	BLinePoint parse_bline_point(xmlpp::Element *node);
 
 	Keyframe parse_keyframe(xmlpp::Element *node,Canvas::Handle canvas);
 
@@ -163,7 +160,6 @@ private:
 
 	etl::handle<ValueNode_Animated> parse_animated(xmlpp::Element *node,Canvas::Handle canvas);
 	etl::handle<ValueNode_Subtract> parse_subtract(xmlpp::Element *node,Canvas::Handle canvas);
-	etl::handle<ValueNode_Animated> parse_timedswap(xmlpp::Element *node,Canvas::Handle canvas);
 	etl::handle<LinkableValueNode> parse_linkable_value_node(xmlpp::Element *node,Canvas::Handle canvas);
 	etl::handle<ValueNode_Composite> parse_composite(xmlpp::Element *node,Canvas::Handle canvas);
 	etl::handle<ValueNode_DynamicList> parse_dynamic_list(xmlpp::Element *node,Canvas::Handle canvas);
