@@ -2,10 +2,11 @@
 /*!	\file rect.cpp
 **	\brief Template File
 **
-**	$Id: rect.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: rect.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -51,10 +52,20 @@ Rect
 Rect::full_plane()
 {
 	const double infinity(HUGE_VAL);
-	return Rect(
-		-infinity,
-		-infinity,
-		infinity,
-		infinity
-	);
+	return Rect(-infinity, -infinity, infinity, infinity);
+}
+
+Rect
+Rect::horizontal_strip(const value_type &y1, const value_type &y2)
+{
+	const double infinity(HUGE_VAL);
+	return Rect(-infinity, y1, infinity, y2);
+}
+
+Rect
+Rect::vertical_strip(const value_type &x1, const value_type &x2)
+{
+	int i, j;
+	const double infinity(HUGE_VAL);
+	return Rect(x1, -infinity, x2, infinity);
 }
