@@ -2,10 +2,11 @@
 /*!	\file rect.h
 **	\brief Rectangle Class
 **
-**	$Id: rect.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: rect.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -51,6 +52,9 @@ public:
 
 	static Rect full_plane();
 
+	static Rect horizontal_strip(const value_type &y1, const value_type &y2);
+	static Rect vertical_strip(const value_type &x1, const value_type &x2);
+
 	static Rect zero()
 	{
 		return Rect(
