@@ -2,7 +2,7 @@
 /*!	\file valuenode.h
 **	\brief Template Header
 **
-**	$Id: valuenode.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode.h 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -173,7 +173,7 @@ public:
 public:
 
 	//! Returns the value of the ValueNode at time \a t
-	virtual ValueBase operator()(Time t)const
+	virtual ValueBase operator()(Time /*t*/)const
 		{ return ValueBase(); }
 
 	//! \internal Sets the id of the ValueNode
@@ -256,7 +256,7 @@ public:
 	static Handle create(ValueBase::Type type=ValueBase::TYPE_NIL);
 
 protected:
-	virtual void get_times_vfunc(Node::time_set &set) const {}
+	virtual void get_times_vfunc(Node::time_set &/*set*/) const {}
 }; // END of class PlaceholderValueNode
 
 
