@@ -2,10 +2,11 @@
 /*!	\file valuenode_scale.h
 **	\brief Template Header
 **
-**	$Id: valuenode_scale.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_scale.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -44,7 +45,7 @@ private:
 	ValueNode::RHandle value_node;
 	ValueNode::RHandle scalar;
 
-	ValueNode_Scale();
+	ValueNode_Scale(const ValueBase &value);
 
 public:
 
