@@ -2,10 +2,11 @@
 /*!	\file valuenode_segcalctangent.cpp
 **	\brief Template File
 **
-**	$Id: valuenode_segcalctangent.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_segcalctangent.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -60,8 +61,8 @@ ValueNode_SegCalcTangent::ValueNode_SegCalcTangent(const ValueBase::Type &x):
 	if(x!=ValueBase::TYPE_VECTOR)
 		throw Exception::BadType(ValueBase::type_name(x));
 
-	segment_=ValueNode_Composite::create(ValueBase::TYPE_SEGMENT);
-	amount_=ValueNode_Const::create(Real(0.5));
+	set_link("segment",ValueNode_Const::create(ValueBase::TYPE_SEGMENT));
+	set_link("amount",ValueNode_Const::create(Real(0.5)));
 }
 
 ValueNode_SegCalcTangent*
@@ -101,7 +102,7 @@ ValueNode_SegCalcTangent::get_name()const
 String
 ValueNode_SegCalcTangent::get_local_name()const
 {
-	return _("SegCalcTangent");
+	return _("Segment Tangent");
 }
 
 bool
