@@ -2,10 +2,11 @@
 /*!	\file valuenode_sine.h
 **	\brief Template Header
 **
-**	$Id: valuenode_sine.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_sine.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -40,7 +41,7 @@ class ValueNode_Sine : public LinkableValueNode
 	ValueNode::RHandle angle_;
 	ValueNode::RHandle amp_;
 
-	ValueNode_Sine(const ValueBase::Type &x);
+	ValueNode_Sine(const ValueBase &value);
 
 public:
 
