@@ -2,10 +2,11 @@
 /*!	\file valuenode_subtract.h
 **	\brief Template Header
 **
-**	$Id: valuenode_subtract.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_subtract.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,7 +43,7 @@ struct ValueNode_Subtract : public LinkableValueNode
 
 protected:
 
-	ValueNode_Subtract();
+	ValueNode_Subtract(const ValueBase &value);
 
 private:
 
@@ -99,7 +100,7 @@ public:
 	using synfig::LinkableValueNode::get_link_vfunc;
 	using synfig::LinkableValueNode::set_link_vfunc;
 	static bool check_type(ValueBase::Type type);
-	static ValueNode_Subtract* create(const ValueBase &x=ValueBase());
+	static ValueNode_Subtract* create(const ValueBase &value=ValueBase());
 }; // END of class ValueNode_Subtract
 
 }; // END of namespace synfig
