@@ -2,10 +2,11 @@
 /*!	\file valuenode_timedswap.h
 **	\brief Template Header
 **
-**	$Id: valuenode_timedswap.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_timedswap.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -47,7 +48,7 @@ private:
 	ValueNode::RHandle swap_time;
 	ValueNode::RHandle swap_length;
 
-	ValueNode_TimedSwap(ValueBase::Type id);
+	ValueNode_TimedSwap(const ValueBase &value);
 
 public:
 
@@ -60,11 +61,9 @@ public:
 	bool set_after(const ValueNode::Handle &a);
 	ValueNode::Handle get_after()const;
 
-	void set_swap_time_real(Time x);
 	bool set_swap_time(const ValueNode::Handle &x);
 	ValueNode::Handle get_swap_time()const;
 
-	void set_swap_length_real(Time x);
 	bool set_swap_length(const ValueNode::Handle &x);
 	ValueNode::Handle get_swap_length()const;
 
