@@ -2,10 +2,11 @@
 /*!	\file tool/main.cpp
 **	\brief SYNFIG Tool
 **
-**	$Id: main.cpp 444 2007-04-08 03:42:41Z dooglus $
+**	$Id: main.cpp 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -122,7 +123,7 @@ public:
 	}
 
 	virtual bool
-	amount_complete(int current, int total)
+	amount_complete(int /*current*/, int /*total*/)
 	{
 		return true;
 	}
